@@ -2,4 +2,4 @@ from __future__ import annotations
 
 HOST_NAME = "localhost"
 SERVER_PORT = 8080
-REDIRECT_PATH = "/oauth/return"
+OAUTH_RETURN_PATH = "/oauth/return"
